@@ -265,7 +265,9 @@ class SME_Solver:
                 atmo_file = self.lfs_atmo.get(atmo_source)
 
                 if ext == ".sav":
-                    atmo_grid = SavFile(atmo_file, source=atmo_source)
+                    atmo_grid = SavFile(
+                        atmo_file, source=atmo_source, lfs=self.lfs_atmo
+                    )
 
                     teff = np.unique(atmo_grid.teff)
                     teff = np.min(teff), np.max(teff)
